clear all
close all

% Calculate prn positions
clc
clear all
close all

% Universal constants
mu      =   3.986005e14;            % Value of mu
w_edot  =   7.2921151467e-5;        % Rotational Velocity of earth

% Orbital parameters
a       =   4.2537638e07;           % Semi major axis
ecc     =   0.07;                      % Eccentricity
M0      =   0;                      % Initial mean anomaly
omega   =   0.5/2;                      % Argument of Perigee
i       =   55*pi/180;            % Inclination
OMEGA   =   274*pi/180;              % RAAN



% Time span
TS      =   (01:100:86000);                % In terms of seconds after periapsis

for j = 1:length(TS)

    t = TS(j)
    % Derived Parameters

    n       =   7.2921151467e-5;        % Mean angular velocity
    M       =   M0+n*t;                 % Mean anomaly at cuttent instant
    E       =   lsqnonlin(@Efun,M,[],[],[],M,ecc);
%     E = M;
                                        % Eccentric Anomaly
    r       =   a*(1-ecc*cos(E));       % radial range

    numer   =   sqrt(1-ecc^2)*sin(E)/(1-ecc*cos(E));    % sin (nu)
    denom   =   (cos(E)-ecc)/(1-ecc*cos(E));            % cos (nu)
    nu      =   atan2(numer,denom);                     % nu

    % NOTE:
    % For zero eccentricity the True anomaly, the Eccentric anomaly and the
    % Mean anomaly becomes equal

    u       =   nu + omega;             % Argument of Latitude


    % Coordinates on Orbital plane

    x1      =   r*cos(u);
    y1      =   r*sin(u);


    % Co ordinates on Intermediate frame

    x2= x1;
    y2= y1*cos(i);
    z2= y1*sin(i);


    % Co ordinates in ECI frame

    xi = x2*cos(OMEGA) - y2*sin(OMEGA);
    yi = x2*sin(OMEGA) + y2*cos(OMEGA);
    zi = z2;

    lat= atan2(zi,sqrt(xi^2+yi^2));
          
%     lon= mod(atan2(yi,xi),2*pi)-mod(t*w_edot,2*pi);
%     lon= (atan2(yi,xi)+2*pi)-(t*w_edot+2*pi);
    lon= mod(mod(atan2(yi,xi),2*pi) - mod(t*w_edot,2*pi),2*pi) ;
    
%     if lon<-pi;
%         lon=lon+2*pi;
%     end
    
    % Enter the position in the sat_info database
    sat_info(t,:) = [lat  lon  atan2(yi,xi) t*w_edot ];


end

load('topo.mat','topo','topomap1');
contour(0:359,-89:90,topo,[0 0],'b')
axis equal
box on
set(gca,'XLim',[0 360],'YLim',[-90 90], ...
    'XTick',[0 60 120 180 240 300 360], ...
    'Ytick',[-90 -60 -30 0 30 60 90]);
hold on
scatter(sat_info(1:10:end,2)*180/pi,sat_info(1:10:end,1)*180/pi,2,'.m')

title('GROUND TRACE OF SATELLITES')
xlabel('LONGITUDE (DEGREES)')
ylabel('LATITUDE (DEGREES)')
